(i) to identify the optimal number of clusters.
(ii) to obtain two profiling matrices, one with the corrected peak area and one with the percent of the total corrected area
data(Agilent_quantT_MSclust)header line the first row contains columns' names
first column name of the sample/analysis
second column retention time of the peak
third column corrected peak area (corrArea)
fourth column percent of the total corrected area (PercTotal)
following columns mean relative mass spectrum of the peak (the intensity of one mass fragment (m/z) per column; Mean mass spectrum calculated by averaging 5 percent of the mass spectra surrounding the apex; The intensity of each mass fragment is transformed to a relative percentage of the highest mass fragment per spectrum)